@@ -83,7 +83,7 @@ void Document::set_file_uri(const Glib::ustring& file_uri, bool bEnforceFileExte
 
   m_file_uri = file_uri;
 
-  //Enfore file extension:
+  //Enforce file extension:
   if(bEnforceFileExtension)
     m_file_uri = get_file_uri_with_extension(m_file_uri);
 }
@@ -316,7 +316,7 @@ bool Document::get_read_only() const
       try
       {
         Gnome::Vfs::FilePermissions permissions = Gnome::Vfs::Handle::get_file_info(m_file_uri, Gnome::Vfs::FILE_INFO_GET_ACCESS_RIGHTS)->get_permissions();
-        bool read_only = ((permissions & Gnome::Vfs::PERM_ACCESS_WRITABLE) != Gnome::Vfs::PERM_ACCESS_WRITABLE);
+        const bool read_only = ((permissions & Gnome::Vfs::PERM_ACCESS_WRITABLE) != Gnome::Vfs::PERM_ACCESS_WRITABLE);
         return read_only;
       }
       catch(const Gnome::Vfs::exception& ex)
