@@ -41,7 +41,7 @@ protected:
   //Signal handlers:
   virtual void on_Entry_changed();
 
-  virtual void on_document_load(); //override.
+  virtual bool on_document_load(); //override.
   
   //Child widgets:
   Gtk::VBox m_Box;
